==> twilio-3.80.1.tgz: package/lib/base/RequestClient.d.ts <==
import { HttpMethod } from "../interfaces";
import Response = require("../http/response");

declare class RequestClient {
  constructor(opts?: RequestClient.RequestClientOptions);
  /**
   * Make an HTTP request
   * @param opts The request options
   */
  request<TData>(
    opts: RequestClient.RequestOptions<TData>
  ): Promise<Response<TData>>;
}

declare namespace RequestClient {
  export interface RequestOptions<TData = any, TParams = object> {
    /**
     * The HTTP method
     */
    method: HttpMethod;
    /**
     * The request URI
     */
    uri: string;
    /**
     * The username used for auth
     */
    username?: string;
    /**
     * The password used for auth
     */
    password?: string;
    /**
     * The request headers
     */
    headers?: Headers;
    /**
     * The object of params added as query string to the request
     */
    params?: TParams;
    /**
     * The form data that should be submitted
     */
    data?: TData;
    /**
     * The request timeout in milliseconds
     */
    timeout?: number;
    /**
     * Should the client follow redirects
     */
    allowRedirects?: boolean;
    /**
     * Set to true to use the forever-agent
     */
    forever?: boolean;
  }

  export interface RequestClientOptions {
    /**
     * A timeout in milliseconds. This will be used as the HTTPS agent's socket
     * timeout, and as the default request timeout.
     */
    timeout?: number;
  }

  export interface Headers {
    [header: string]: string;
  }
}

export = RequestClient;

==> twilio-3.82.2.tgz: package/lib/base/RequestClient.d.ts <==
import { HttpMethod } from "../interfaces";
import Response = require("../http/response");

declare class RequestClient {
  constructor(opts?: RequestClient.RequestClientOptions);
  /**
   * Make an HTTP request
   * @param opts The options https.Agent takes in
   */
  request<TData>(
    opts: RequestClient.RequestOptions<TData>
  ): Promise<Response<TData>>;
}

declare namespace RequestClient {
  export interface RequestOptions<TData = any, TParams = object> {
    /**
     * The HTTP method
     */
    method: HttpMethod;
    /**
     * The request URI
     */
    uri: string;
    /**
     * The username used for auth
     */
    username?: string;
    /**
     * The password used for auth
     */
    password?: string;
    /**
     * The request headers
     */
    headers?: Headers;
    /**
     * The object of params added as query string to the request
     */
    params?: TParams;
    /**
     * The form data that should be submitted
     */
    data?: TData;
    /**
     * The request timeout in milliseconds
     */
    timeout?: number;
    /**
     * Should the client follow redirects
     */
    allowRedirects?: boolean;
    /**
     * Set to true to use the forever-agent
     */
    forever?: boolean;
  }

  export interface RequestClientOptions {
    /**
     * A timeout in milliseconds. This will be used as the HTTPS agent's socket
     * timeout, AND as the default request timeout.
     */
    timeout?: number;
    /**
     * https.Agent keepAlive option
     */
    keepAlive?: boolean;
    /**
     * https.Agent keepAliveMSecs option
     */
    keepAliveMsecs?: number;
    /**
     * https.Agent maxSockets option
     */
    maxSockets?: number;
    /**
     * https.Agent maxTotalSockets option
     */
    maxTotalSockets?: number;
    /**
     * https.Agent maxFreeSockets option
     */
    maxFreeSockets?: number;
    /**
     * https.Agent scheduling option
     */
    scheduling?: string;
  }

  export interface Headers {
    [header: string]: string;
  }
}

export = RequestClient;
